from django.shortcuts import render, get_object_or_404, redirect
from django.http import HttpResponse


from .models import Transaction, TransactionForm, Invoice


def index(request):
    _transactions = Transaction.objects.order_by("date")[:5]
    context = {
        "transactions": _transactions,
    }
    return render(request, "main/index.html", context)


def transaction(request, uuid):
    _transaction = get_object_or_404(Transaction, id=uuid)
    _invoices = Invoice.objects.filter(transaction=_transaction)
    return render(
        request,
        "main/transaction.html",
        {
            "transaction": _transaction,
            "form": TransactionForm(instance=_transaction),
            "invoices": _invoices,
        },
    )


def update_transaction(request, uuid):
    _transaction = get_object_or_404(Transaction, id=uuid)
    _form = TransactionForm(request.POST, instance=_transaction)
    _form.save()
    return redirect(transaction, uuid=uuid)


def invoice(request, uuid):
    _invoice = get_object_or_404(Invoice, id=uuid)
    with _invoice.file.open() as _file:
        return HttpResponse(_file.read(), content_type="application/pdf")
